=======
AuDoLab
=======

.. image:: https://img.shields.io/pypi/v/AuDoLab.svg
        :target: https://pypi.python.org/pypi/AuDoLab

.. image:: https://img.shields.io/travis/ArneTillmann/AuDoLab.svg
        :target: https://travis-ci.com/ArneTillmann/AuDoLab

.. image:: https://readthedocs.org/projects/AuDoLab/badge/?version=latest
        :target: https://AuDoLab.readthedocs.io/en/latest/?version=latest
..
  :alt: Documentation Status

 With AuDoLab you can perform Latend Direchlet Allocation on highly imbalanced datasets.


* Free software: GNU General Public License v3
* Documentation: https://AuDoLab.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
